@@ -31,9 +31,9 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <libgnomeui/libgnomeui.h>
+#include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <libgpm.h>
+#include <gst/gst.h>
 
 #include "gpm-stock-icons.h"
 #include "gpm-common.h"
@@ -42,14 +42,12 @@
 #include "gpm-manager.h"
 #include "dbus/xdg-power-management-core.h"
 
-static void gpm_exit (GpmManager *manager);
-
 /**
  * gpm_object_register:
  * @connection: What we want to register to
  * @object: The GObject we want to register
  *
- * Register org.gnome.PowerManager on the session bus.
+ * Register org.freedesktop.PowerManagement on the session bus.
  * This function MUST be called before DBUS service will work.
  *
  * Return value: success
@@ -99,18 +97,6 @@ gpm_object_register (DBusGConnection *connection,
 	return TRUE;
 }
 
-/**
- * gpm_exit:
- * @manager: This manager class instance
- **/
-static void
-gpm_exit (GpmManager *manager)
-{
-	gpm_stock_icons_shutdown ();
-	gpm_debug_shutdown ();
-	exit (0);
-}
-
 /**
  * timed_exit_cb:
  * @loop: The main loop
@@ -133,18 +119,16 @@ int
 main (int argc, char *argv[])
 {
 	GMainLoop *loop;
-	GnomeClient *master;
-	GnomeClientFlags flags;
 	DBusGConnection *system_connection;
 	DBusGConnection *session_connection;
 	gboolean verbose = FALSE;
+	gboolean version = FALSE;
 	gboolean no_daemon = FALSE;
 	gboolean timed_exit = FALSE;
 	gboolean immediate_exit = FALSE;
 	GpmManager *manager = NULL;
 	GError *error = NULL;
 	GOptionContext *context;
- 	GnomeProgram *program;
 	char **debugoptions = NULL;
 	int i;
 
@@ -153,41 +137,38 @@ main (int argc, char *argv[])
 		  N_("Do not daemonize"), NULL },
 		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, &verbose,
 		  N_("Show extra debugging information"), NULL },
+		{ "version", '\0', 0, G_OPTION_ARG_NONE, &version,
+		  N_("Show version of installed program and exit"), NULL },
 		{ "timed-exit", '\0', 0, G_OPTION_ARG_NONE, &timed_exit,
 		  N_("Exit after a small delay (for debugging)"), NULL },
 		{ "immediate-exit", '\0', 0, G_OPTION_ARG_NONE, &immediate_exit,
-		  N_("Exit after a the manager has loaded (for debugging)"), NULL },
+		  N_("Exit after the manager has loaded (for debugging)"), NULL },
 		{ "debug", '\0', 0, G_OPTION_ARG_STRING_ARRAY, &debugoptions,
 		  N_("Debug specific files, e.g. power"), NULL },
 		{ NULL}
 	};
 
-	context = g_option_context_new (_("GNOME Power Manager"));
+	context = g_option_context_new (N_("GNOME Power Manager"));
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
+	g_option_context_add_group (context, gtk_get_option_group (FALSE));
+	g_option_context_parse (context, &argc, &argv, NULL);
 
-	program = gnome_program_init (argv[0], VERSION,
-			   	      LIBGNOMEUI_MODULE, argc, argv,
-			    	      GNOME_PROGRAM_STANDARD_PROPERTIES,
-			    	      GNOME_PARAM_GOPTION_CONTEXT, context,
-			    	      GNOME_PARAM_HUMAN_READABLE_NAME, GPM_NAME,
-			    	      NULL);
+	/* manually poke gtk, it seems gtk_get_option_group isn't good enough */
+	gtk_init (&argc, &argv);
 
-	master = gnome_master_client ();
-	flags = gnome_client_get_flags (master);
+	g_set_application_name (GPM_NAME);
 
-	if (flags & GNOME_CLIENT_IS_CONNECTED) {
-		/* We'll disable this as users are getting constant crashes */
-		/* gnome_client_set_restart_style (master, GNOME_RESTART_IMMEDIATELY);*/
-		gnome_client_flush (master);
+	if (version == TRUE) {
+		g_print ("Version %s\n", VERSION);
+		return 0;
 	}
 
-	g_signal_connect (GTK_OBJECT (master), "die", G_CALLBACK (gpm_exit), manager);
-
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
 	dbus_g_thread_init ();
@@ -208,6 +189,7 @@ main (int argc, char *argv[])
 
 	gpm_debug ("GNOME %s %s", GPM_NAME, VERSION);
 
+if (0) {
 	/* check dbus connections, exit if not valid */
 	system_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
 	if (error) {
@@ -218,6 +200,7 @@ main (int argc, char *argv[])
 			   "It is <b>strongly recommended</b> you reboot "
 			   "your computer after starting this service.");
 	}
+}
 
 	session_connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	if (error) {
@@ -229,15 +212,18 @@ main (int argc, char *argv[])
 			   "or gnome startup when you start a new session.");
 	}
 
-	if (gpm_stock_icons_init() == FALSE) {
-		gpm_error ("Cannot continue without stock icons");
-	}
+	/* Add application specific icons to search path */
+	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+                                           GPM_DATA G_DIR_SEPARATOR_S "icons");
+
+	/* initialise gstreamer */
+	gst_init (&argc, &argv);
 
 	/* create a new gui object */
 	manager = gpm_manager_new ();
 
 	if (!gpm_object_register (session_connection, G_OBJECT (manager))) {
-		gpm_warning ("%s is already running in this session.", GPM_NAME);
+		gpm_error ("%s is already running in this session.", GPM_NAME);
 		return 0;
 	}
 
@@ -253,15 +239,12 @@ main (int argc, char *argv[])
 		g_main_loop_run (loop);
 	}
 
-	gpm_stock_icons_shutdown ();
+	g_main_loop_unref (loop);
 	gpm_debug_shutdown ();
 
+	/* rip down gstreamer */
+	gst_deinit ();
 	g_object_unref (manager);
-	g_object_unref (program);
-	/*
-	In uncommented, valgrind reports an invalid read
-	g_option_context_free (context);
-	*/
 
 	return 0;
 }
