@@ -48,7 +48,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint	     signals [LAST_SIGNAL] = { 0, };
+static guint	     signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GpmRefcount, gpm_refcount, G_TYPE_OBJECT)
 
@@ -214,6 +214,7 @@ gpm_refcount_finalize (GObject *object)
 	refcount = GPM_REFCOUNT (object);
 	refcount->priv = GPM_REFCOUNT_GET_PRIVATE (refcount);
 	/* emit signal ? */
+	G_OBJECT_CLASS (gpm_refcount_parent_class)->finalize (object);
 }
 
 /**
